;; Ethno-Cultural Tag Model v1.9 (ect-v1.9 public)
;; dave@davidhales.com, May 2018
;; Centre for Policy Modelling, Manchester Met. http://cfpm.org
;; developed in Netlogo 5.3.1
;;
;; This model is associated with the article:
;;   Hales, D. & Edmonds, B. (in press) Intra-generational cultural evolution and ethnocentrism.
;;   Journal of Conflict Resolution.
;;
;; user interface supplies following main model parameters:
;; N (number-of-agents), NE (number-of-tags), M (strategy-mutate-prob)
;; cost (cost payoff of a donation), benefit (benefit payoff of donation)
;; GB (game in-group bias) probability to game interact with in-group rather than randomly selected agent
;; LB (learning in-group bias) probability to imitate from in-group rather than randomly selected agent

;; === global variables
globals [
         ;; some constants
         donate         ;; constant meaning agent donates
         shirk          ;; constant meaning agent shirks
         ;; some parameters as named internally
         number-of-agents     ;; name of internal parameter for N
         number-of-tags       ;; number of distinct cultural tags is set to N
         number-of-eth        ;; name of internal parameter for NE
         strategy-mutate-prob ;; name of internal parameter for M
         tag-mutate-prob      ;; set to 10M
         ;; some bookkeeping variables:
         donations      ;; total number of donation made in a cycle
         inter-eth-don  ;; total number of inter-ethnic donations made in a cycle
         sln  ;; proportions of the 4 different in-group selector types in the population
         slc
         sle
         slb
         stSS ;; proportions of the 4 different strategy types
         stDS
         stSD
         stDD
       ]

;; === agent declarations
breed [agents agent]  ;; create a breed of turtles called agents
agents-own [
            etag         ;; ethnic marker (fixed)
            ctag         ;; cultural tag (can evolve)
            selector     ;; in-group selector type: 0=none, 1=cultural tag only, 2=ethnic marker only, 3=both
            in-strategy  ;; strategy to use for in-group partners (donate or shirk)
            out-strategy ;; strategy to use for out-group partners (donate or shirk)
            payoff       ;; stores accumulated payoff over interaction phase
            newCopy      ;; flag that indicates if agent has already imitated within current imitation phase
            new-ctag     ;; new- variables store new traits obtained from an imitation to be used in next interaction phase
            new-selector
            new-in-strategy
            new-out-strategy
            ]

;; === SETUP button function
to setup
  clear-all     ;; wipe population
  set donate 1  ;; constant for donate strategy
  set shirk 0   ;; constant for shirk (dont donate) strategy
  ;; --- set internal parameters from the GUI paramters
  set number-of-agents N
  set number-of-tags N
  set number-of-eth NE
  set strategy-mutate-prob M
  set tag-mutate-prob 10 * M
  ;; --- initialise agents
  create-agents number-of-agents [
    ;; set traits and ethnic marker
    set selector random 4       ;; random in-group selector: 0=none, 1=cultural tag, 2=ethnic marker, 3=both
    set in-strategy random 2    ;; random in-group strategy: 0=shirk, 1=donate
    set out-strategy random 2   ;; random out-group strategy:0=shirk, 1=donate
    set ctag (random number-of-tags) ;; random cultural tag
    ;; do an equal split of ethnic tags over agents
    let e-group-size int (number-of-agents / number-of-eth)  ;; size of an ethnic group
    set etag int (who / e-group-size) ;; who is the unique agent ID from 0..number-of-agents-1
    if etag > (number-of-eth - 1) [set etag (random number-of-eth)]  ;; leftover agents get random etag
    ;; other agent actions
    set payoff 0        ;; zero cumulative payoff from playing donation games
    set newCopy false   ;; flag indicating if new traits have been imitated
    set shape "circle"
    set size 1
    colour-agent-by-strategy-type
    setposCircleStack   ;; place agents on visual grid
  ]
  reset-ticks
end

;; === GO button function
to go
 collect-statistics  ;; collect population statsitics and place agents on visual grid

 ;; --- interaction phase - locate partners and play donation game updating payoffs
 interaction-phase

 ;; --- imitatation phase - agents decide if to copy others using payoffs and tournament rule
 imitation-phase

 ;; --- innovation phase - mutate traits of agents by relevant probabilities
 innovation-phase

 ;; finish cycle
 tick
end

;; === zero cycle level bookkeeping stats
to zero-stats
 set donations 0
 set inter-eth-don 0
 set sln 0 ;; proportions of each in-group selector type
 set slc 0
 set sle 0
 set slb 0
 set stSS 0 ;; proportions of each strategy type
 set stDS 0
 set stSD 0
 set stDD 0
end

;; === collect some stratistics and place agents on grid
to collect-statistics
 zero-stats ; first zero the stats
 ;; --- count selector and stratey types from each agent into bookkeeping variables
 ask agents [
   colour-agent-by-strategy-type
   setposCircleStack  ; place agent on visual grid
   count-selector-types
   count-strategy-types
 ]
 calc-proportions  ;; change counts to proprtions
end

;; === innovation-phase - mutation
to innovation-phase
   ask agents [
    if prob strategy-mutate-prob [ set in-strategy flip-strat in-strategy ]     ;; mutate in-group strategy
    if prob strategy-mutate-prob [ set out-strategy flip-strat out-strategy ]   ;; mutate out-group strategy
    if prob strategy-mutate-prob [ set selector random 4 ]                      ;; mutate in-group selector
    if prob tag-mutate-prob [ set ctag random number-of-tags ]                  ;; mutate ctag
  ]
end

;; === interaction-phase play donation games
to interaction-phase
  ask agents [ interaction ]    ;; each agent plays donation game
end

;; === imitation-phase - reproduction of traits
to imitation-phase
 ask agents [imitation]   ;; do imitation for each agent
 ask agents [             ;; copy over any imitated traits and zero all agent payoffs
   if newCopy [
       set ctag new-ctag
       set in-strategy new-in-strategy
       set out-strategy new-out-strategy
       set selector new-selector
       set newCopy false
   ]
   set payoff 0
 ]
end

;; === do an imitation - agent copies others to temp variables so they continue to be allowed to be copied by other agents
to imitation
   let partner nobody
   if prob LB [set partner one-of other agents with [in-their-group? myself]]              ;; with prob LB select a tag match parter
   if partner = nobody [set partner one-of other agents]          ;; get rnd partner if no partner currently found
   if payoff < [payoff] of partner [imitate partner]         ;; if partner doing better copy it
end

;; === imitate copyable traits from partner-agent to temp variables
to imitate [partner-agent]
   if partner-agent != nobody [          ;; only imitate if partner-agent exists
     set new-ctag [ctag] of partner-agent
     set new-in-strategy [in-strategy] of partner-agent
     set new-out-strategy [out-strategy] of partner-agent
     set new-selector [selector] of partner-agent
     set newCopy true                    ;; flag a newCopy (imitation) has been made for this agent
     ]
end

;; === game interact with game-in-group-bias. Select an in-group partner with prob. GIGSB in one exists
to interaction
  let partner nobody
  if prob GB [set partner one-of other agents with [in-their-group? myself]]   ;; with GB get in-group partner
  if partner = nobody [set partner one-of other agents]
  play-game partner
end

;; === game interact with partner-agent - based on selector, tags and strategies of partner decide if to donate or not to other agent
;; if partner is determined to be in my in-group then enact in-group strategy otherwise out-group strategy
to play-game [partner-agent]
  ifelse in-my-group? partner-agent
    [if in-strategy = donate [donate-to partner-agent]]   ;; if partner is within in-group then use in-strategy
    [if out-strategy = donate [donate-to partner-agent]]  ;; else use out-strategy
end

;; === make a donation from this agent to partner-agent
to donate-to [partner-agent]
  ask partner-agent [set payoff payoff + benefit]
  set payoff payoff - cost
  ;; update bookkeeping globals
  set donations donations + 1          ;; count donations
  if etag != [etag] of partner-agent [set inter-eth-don inter-eth-don + 1]    ;; count inter-ethnic donations
end

;; === use in-group selector of partner, etag and ctag to determine if partner-agent thinks I am in THEIR in-group
;; note: this does not necessarily mean I think they are in my in-group. This reporter is useful for using with the
;; "one-of other agents with" queries. Essentially we ask the queried agent to determine if I think they are in my in-group
;; based on my group selector
to-report in-their-group? [partner-agent]
  let p-selector [selector] of partner-agent
  if p-selector = 1 [                                       ;; cultural (only match ctag)
    report (ctag = [ctag] of partner-agent)
  ]
  if p-selector = 2 [                                       ;; ethnic (only match etag)
    report (etag = [etag] of partner-agent)
  ]
  if p-selector = 3 [                                       ;; both (match ctag and etag)
    ifelse (etag != [etag] of partner-agent)
      [report false]
      [report (ctag = [ctag] of partner-agent)]
  ]
  report true
end

;; === use my in-group selector, etag and ctag to determine if I think partner-agent is in MY in-group
to-report in-my-group? [partner-agent]
  let result true
  ifelse selector = 1 [if ctag != [ctag] of partner-agent [set result false]]        ;; cultural (only match ctag)
    [ ifelse selector = 2 [if etag != [etag] of partner-agent [set result false]]    ;; ethnic (only match etag)
       [ if selector = 3 [if (etag != [etag] of partner-agent) or
           (ctag != [ctag] of partner-agent) [set result false]]                     ;; both (match ctag and etag)
       ]
    ]
    report result
end

;; === flip donate / shirk strategy
to-report flip-strat [strat]
  ifelse strat = donate [report shirk] [report donate]
end

;; === prob - returns value "TRUE" with probability nm
to-report prob [nm]
  report (random-float 1 < nm)
end

;; === report proportion of game interactions that produced donation
to-report donation-rate
  report donations / (number-of-agents)
end

;; === report proportion of donations that were inter-ethnic
;; if no donations were made then report 0
to-report inter-ethnic-donation-rate
  ifelse donations > 0 [report inter-eth-don / donations] [report 0]  ;; proportion of donations
end

;; === count in-group selector types into globals: sln = none, slc = cultural, sle = ethnic, slb = both
to count-selector-types
  if selector = 0 [set sln sln + 1]
  if selector = 1 [set slc slc + 1]
  if selector = 2 [set sle sle + 1]
  if selector = 3 [set slb slb + 1]
end

;; === count strategy types: stSD = in-group shirk, out-group donate, stDS = in-group donate, out-group shirk
;; stSS = shirk on all, stDD = donate to all
to count-strategy-types
  colour-agent-by-strategy-type
  if color = blue [set stSS stSS + 1]
  if color = red [set stDS stDS + 1]
  if color = green [set stSD stSD + 1]
  if color = yellow [set stDD stDD + 1]
end

;; === normalise the stratety and selector type counts to proportions of the population
to calc-proportions
  set sln sln / number-of-agents    ;; selector counts
  set slc slc / number-of-agents
  set sle sle / number-of-agents
  set slb slb / number-of-agents
  set stSS stSS / number-of-agents  ;; strategy counts
  set stDS stDS / number-of-agents
  set stSD stSD / number-of-agents
  set stDD stDD / number-of-agents
end

;; === visualise agents around a ring where wich position on the ring is a unique ctag
;; agents sharing shame ctag are stacked outward on top of each other
;; hence straight lines of agents represent those sharing a ctag
;; colour each agent based on in-group / out-group strategy
to setposCircleStack
  set size 1
  set shape "circle"
  ;colour-agent-by-strategy-type
  setxy 0 0
  facexy 0 1
  right ctag * (360 / number-of-tags)
  forward 5
  let move-count 0
  ;; move forward until there is space or max number of moves - stops turtle going over edge of world grid
  while [ (any? other agents-here) and move-count < 45] ;; 45 assumes world grid is square of size (50,50,-50,-50)
     [forward 1
      set move-count move-count + 1]
end

;; === set colour of agent based on current strategy type blue = SS, green = SD, red = DS, yellow = DD
;; where DS = donate to in-group, shirk on out-group. SD = shirk on in-group, donate to out-group.
;; DD = donate to everyone, SS = shirk on everyone.
to colour-agent-by-strategy-type
  if in-strategy = donate and out-strategy = donate [ set color yellow ] ;dd
  if in-strategy = shirk  and out-strategy = shirk  [ set color blue ]   ;ss
  if in-strategy = donate and out-strategy = shirk  [ set color red ]    ;ds
  if in-strategy = shirk  and out-strategy = donate [ set color green ]  ;sd
end
@#$#@#$#@
GRAPHICS-WINDOW
782
10
1196
445
50
50
4.0
1
10
1
1
1
0
1
1
1
-50
50
-50
50
1
1
1
ticks
30.0

BUTTON
15
128
70
161
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
138
128
193
161
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
210
12
777
166
donation rates
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"dr" 1.0 0 -2674135 true "" "plot donation-rate"
"ie" 1.0 0 -13345367 true "" "plot inter-ethnic-donation-rate"

BUTTON
76
128
131
161
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
13
382
105
415
cost
cost
0
1
0.1
0.1
1
NIL
HORIZONTAL

SLIDER
108
382
200
415
benefit
benefit
0
1
0.2
0.1
1
NIL
HORIZONTAL

PLOT
210
168
777
318
strategy types
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"ds" 1.0 0 -2674135 true "" "plot stDS"
"ss" 1.0 0 -13345367 true "" "plot stSS"
"dd" 1.0 0 -1184463 true "" "plot stDD"
"sd" 1.0 0 -10899396 true "" "plot stSD"

SLIDER
107
232
199
265
NE
NE
1
8
2
1
1
NIL
HORIZONTAL

PLOT
210
320
777
470
in-group selectors
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"sn" 1.0 0 -16777216 true "" "plot sln"
"sc" 1.0 0 -2674135 true "" "plot slc"
"se" 1.0 0 -13345367 true "" "plot sle"
"sb" 1.0 0 -10899396 true "" "plot slb"

TEXTBOX
786
452
1191
502
Agents are stacked by tag around a ring. A line indicates all agents sharing a given tag. Colours show strategy types: ds=red, ss=blue, dd=yellow, sd=green. Note: in-group selectors and ethnicities not shown
11
0.0
1

SLIDER
13
232
105
265
N
N
10
1000
100
10
1
NIL
HORIZONTAL

SLIDER
12
281
104
314
M
M
0
0.1
0.001
0.001
1
NIL
HORIZONTAL

TEXTBOX
24
217
102
235
No. of agents:
11
0.0
1

TEXTBOX
108
218
208
236
No. of Ethnicities:
11
0.0
1

TEXTBOX
22
267
100
285
Mutation rate:
11
0.0
1

TEXTBOX
56
366
156
384
donation payoffs:
11
0.0
1

TEXTBOX
337
149
606
167
dr=donation rate,  ie=inter-ethnic donation rate
11
0.0
1

TEXTBOX
268
301
713
319
donate to: ds=ingroup only, ss=nobody,  dd=everybody, sd=outgroup only
11
0.0
1

TEXTBOX
360
453
616
471
sn=none, sc=cultural, se=ethnic, sb=both
11
0.0
1

SLIDER
12
436
104
469
GB
GB
0
1
1
0.1
1
NIL
HORIZONTAL

SLIDER
107
436
199
469
LB
LB
0
1
0
0.1
1
NIL
HORIZONTAL

TEXTBOX
28
421
87
439
Game Bias:
11
0.0
1

TEXTBOX
118
422
198
440
Learning Bias:
11
0.0
1

TEXTBOX
12
194
162
213
Main Parameters:
15
0.0
1

TEXTBOX
8
345
192
365
Further Parameters:
15
0.0
1

TEXTBOX
7
105
86
124
Controls:
15
0.0
1

TEXTBOX
13
12
191
56
Ethno-Cultural Tag model (ECT)
18
0.0
1

@#$#@#$#@
## WHAT IS IT?

The Ethno-Cultural Tag model (ECT) explores the evolution of ethnocentrism in an artificial society of interacting agents.

### motivation

Ethnocentrism denotes a positive orientation towards those sharing the same ethnicity and a negative one towards others, potentially leading to discriminatory behaviour.

How can ethnocentric discriminatory behaviour suddenly emerge in a population that initially has no ethnocentric predispositions?

Many previous evolutionary models of ethnocentrism focus on long-term change in which ethnicities themselves evolve over many generations along with discriminatory behaviours. The ECT model focuses on short-term rapid **_intra-generational_** change in which ethnicities are fixed but behaviours and cultural group memberships change within the life-times of the agents.

### model outline
Agents can distinguish between others based on a **_fixed_** ethnic marker and / or an  **_evolving_** cultural tag. These two observables are used by agents to decide if to make altruistic donations to other agents.

The ethnic marker represents ethnic group membership. The cultural tag represents more fluid cultural markers such as club membership, clothing style, expressed opinions etc.

The interesting aspect of the model is that agents evolve (through imitation):

* the way they classify others as part of their in- or out-group,
* if to donate or not to the in-group and / or the out-group, and
* the cultural tag,

whereas the ethnic marker is fixed for each agent and does not evolve.

### basic results
It is found that agents, mostly, donate to their in-group only, which they define by the cultural tag only. This means agents ignore the ethnic marker completely thus producing no ethnocentric behaviour.

However, more interestingly, it is also found that in a significant minority of cases agents come to classify their in-group based on **_both_** the ethnic marker and the cultural tag combined. In these cases a sudden upsurge of ethnocentric-like behaviour can emerge in the population where agents only donate to those with the same ethnic marker as themselves (in addition to the same cultural tag).

This latter result is interesting because agents have no in-built predisposition to favour their own ethnicities or even to classify others based on ethnicity, but these evolve intra-generationally, through imitation, while ethnicity is fixed.

This happens because some cultural groups happen to form, purely coincidentally, which are ethnically homogenous in their early stages. This creates the conditions to allow discrimination based on both ethnicity and cultural tag to evolve. This discrimination is multiplied when such groups become larger through imitation.



## HOW IT WORKS

A population of N agents interact by playing donation games with selected partners in which they decide if to help (donate) or not help (shirk). Donation incurs a cost to the giver and provides a benefit to the receiver (where cost < benefit). Each agent plays one donation game with a selected partner in each cycle accumulating their individual payoff (costs - benefits).

Agent store several traits: a cultural tag, an ethnic marker, a strategy and an in-group selector. The tag, strategy and selector evolve through imitation (replication) and innovation (mutation). Agents imitate those who get a better payoff than themselves by copying their cultural tag, strategy and in-group selector. Agents periodically mutate their strategy, selector and tag.  Mutation involves probabilistically changing these traits to a random value.

Agents select game partners randomly from within their in-group. If there are no other members of an in-group then agents select a random partner from the entire population. Imitation partners are randomly selected from the entire population.

### agent traits

The _cultural tag_ indicates cultural group / identity membership and takes one of N values. Each agent is initially allocated a random tag form this range.

The _ethnic marker_ indicates ethnicity and is fixed and never changes. The population is divided equally between NE different ethnicities.

The _in-group selector_ specifies how an agent defines its in-group and is one of:

* those with the same ethnic marker as itself (ethnic);
* those with the same cultural tag as itself (cultural);
* those with the same ethnic maker and the same cultural tag (both); or
* any other agent without restriction (none)

The _strategy_ determines if the agent donates or shirks during a game interaction. It takes one of four values:

* unconditionally shirk on all (ss);
* unconditionally donate to all (dd);
* donate to in-group but shirk on out-group (ds);
* shirk on in-group but donate to out-group (sd).

Each agents is initially allocated a random in-group selector and strategy from the above ranges.

### model event sequencing

The model iterates through three phases in each cycle (or tick):

1. Interaction phase - each agent plays one game with a selected partner.
2. Imitation phase - each agent imitates a selected partner if they got a higher payoff.
3. Innovation phase - each agent randomly mutates their tag, strategy and selector.

Here is an outline algorithm:

    Initialize population with random traits and fixed ethnicities
    Loop for some number of cycles:
      Set all agent payoffs to zero
      // --- game interaction phase
      Loop for each agent (a) in random order from the population:
        agent (a) selects a random agent (b) from it's in-group
        If no agents within (a)'s in-group then
          select (b) randomly from population
        agent (a) decides if to donate to (b) based on its strategy
      // --- imitation phase
      Loop for each agent (a) in random order from the population:
        Select an agent (b) randomly from population
        If agent (b)’s payoff > agent (a)’s payoff then:
          Agent (a) copies agent (b)’s strategy, tag and selector
      // --- innovation phase
      Loop for each agent (a) in the population:
        with low probability mutate agent traits





## HOW TO USE IT


### Controls
Press the "setup" button to initialise the population before staring the model. Press the "go" button to start the model. Press "go" again to stop the model. The "step" button advances the model by one cycle only.

### Main Parameters
Set the values of the main parameters N (population size), NE (number of ethnicities)  and M (mutation rate) here. Be aware that larger N causes the model to run more slowly.


These parameter values are used when the model in initialised with the "setup" button hence changing their values during model execution will have no effect until the "setup" button is pressed again to reinitialise the population.

### Further Parameters
These parameters allow for further exploration of the model behaviour outside the standard behaviours so far described.

The cost and benefit payoffs of donation games can be changed from their default values here. Also GB (game bias) and LB (learning bias) values can be changed. These latter parameters change the way partners are selected for donation games and imitation.

GB is the probability that an agent will look for a game partner within it's in-group. Similarly, LB is used when selecting an imitation partner. Hence if both GB = LB = 0 then all interaction is random over the entire population (mean-field). Conversely GB = LB = 1 would mean agents always look for interaction within their in-group. The default values of GB = 1 and LB = 0 are identical to the behaviour described above in the outline algorithm.

### Understanding the plots
Three plots shown time series for: donation rates, strategy types, in-group selectors.

_Donation rates plot_: The donation rate (dr) is the proportion of games played that resulted in a donation being made. The inter-ethnic donation rate (ie) is the proportion of those donations made that were between agents with different ethnicities. If no ethnic discrimination was occurring we would expect ie = 1 / NE. This means that for two ethnicities (NE=2) we would expect ie = 0.5. A consistently lower value indicates ethnic discrimination.

_Strategy types plot_: Shows the proportion of each of the four different strategy types (ss, dd, ds, sd) in the population.

_in-group selectors plot_: shows the proportion of each of the four different in-group selector types (ethnic, cultural, both, none) in the population.

### Visual grid
The grid visualises agents by putting them on a ring stacked. The position on the ring indicates the agent cultural tag value. The height of the stack indicates how many agents share the tag (i.e. the size of the cultural tag group). The colours indicate the strategy type of the agent. The dynamics over time show how agents rapidly change their cultural tags and strategies.






## THINGS TO NOTICE

Reasonably quick and interesting dynamics can be observed for main parameters: N=100, NE=2 and M=0.001 (and the default further parameters of: cost=01, benefit=0.2, GB=1, LB=0).

Notice that the donation rate (dr) quickly goes high in most cases - shown in the "donation rates" plot at the top. This indicates agents evolve altruistic donation.

Looking in the visual grid, notice that over time a small number of large red cultural tag groups repeatedly form, then turn blue and then quickly dissolve. This indicates groups forming sharing the same cultural tag and holding the ds strategy (in-group donate, out-group shirk). The growth of the ds strategy in the population can be seen in the "strategy types" plot. When groups turn blue this indicates invasion of the group by free-rider mutants holding the ss strategy (in-group and out-group shirk).

Examining the "in-group selector plot" shows that either the cultural (sc) or both (sb) selectors tends to dominate the population often competing and changing places as the majority selector.

Notice that when the both selector dominates the inter-ethnic donation rate (ie) goes low in the "donation rates" plot, indicating that few donations are being made between those with different ethnicites. For two ethnicities (NE=2) we would expect the ie rate to be 0.5 if there was no ethnic discrimination in donation choices.

Notice that the ethnic in-group selector (se) rarely gains any significant hold in the population meaning that agents rarely define their in-groups solely with reference to the ethnic marker meaning that pure ethnocentrism does not evolve.





## THINGS TO TRY

Try repeated runs - restarting the model by clicking the "setup" button after several hundred cycles. Notice that sometimes the cultural selector (sc) and sometimes the both selector (sb) becomes dominant for long periods.

Try increasing and reducing the number of agents (N) and restarting the model. How does this effect the dynamics of groups and donation rate (dr)?

Try increasing and reducing the mutation rate (M) and restarting the model. How does this effect the dynamics of the groups and donation rate (dr)?

Try varying the cost and benefit parameters and examine how this effects the overall donation rates and dynamics.

It is interesting to try different GB and LB values. Try setting them both to zero (for mean-field interactions), both to one (so all interaction occur with the in-group) or both to 0.5 (so half of the interaction are in-group). It is also interesting to try setting them to their default values of GB=1, LB=0 and then reduce the GB value a little at a time to see how this effects results.




## EXTENDING THE MODEL

Ethnic minorities:

Currently the model equally splits agents between the number of ethnicities. Different distributions of ethnicities in the population could be easily implemented by changing the "setup" function in the code. For example it would be interest to explore what happens when one ethnicity is a significant minority.

Migration:

Currently the model comprises a fixed population of agents. However, it would easy to implement the migration of new agents into the existing host population by changing the "go" function in the code to include a new phase in which migrants are added, either slowly over time or in a single cohort at a given cycle. This would be particularly interesting to combine with the new entrants being part of an ethnic minority.



## RELATED MODELS

The ECT model can be compared to the Hammond and Axelrod (2006) model which relates to long-term evolution of a dynamic population in a spatial environment:

In this model agents die, reproduce and evolve their ethnicities as well as their in-group and out-group strategies. Also migrants enter the population at a given rate over time.

There is a NetLogo implementation of the Hammond & Axelrod model in the built-in NetLogo models library. Find it from the menu: File > Models Library > Sample Models > Social Science > Ethnocentrism

## CREDITS AND REFERENCES

Two articles that refer to previous similar models are:

- Hales, D. (2000) Cooperation without memory or space: Tags, groups and the prisoner's dilemma. In S. Moss & P. Davidsson (Eds.), Multi-Agent-Based Simulation, 1979, 157-166.

- Hammond, R. & Axelrod, R. (2006) The Evolution of Ethnocentrism. Journal of Conflict Resolution, December 2006, 50: 926-936.

More details of the ECT model and results can be found in:

- Hales, D. & Edmonds, B. (2015) Culture trumps ethnicity! – Intra-generational cultural evolution and ethnocentrism in an artificial society. Centre for Policy Modelling Discussion Paper CPM 15-226, Manchester, UK. http://cfpm.org/discussionpapers/152

- Hales, D. & Edmonds, B. (in press) Intra-generational cultural evolution and ethnocentrism. Journal of Conflict Resolution.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
